@@ -12,12 +12,14 @@ pub mod attachment_projection;
 pub use self::attachment_projection::AttachmentProjection;
 pub mod basic_auth_options;
 pub use self::basic_auth_options::BasicAuthOptions;
-pub mod bounce;
-pub use self::bounce::Bounce;
 pub mod bounce_projection;
 pub use self::bounce_projection::BounceProjection;
 pub mod bounce_recipient;
 pub use self::bounce_recipient::BounceRecipient;
+pub mod bounced_email_dto;
+pub use self::bounced_email_dto::BouncedEmailDto;
+pub mod bounced_recipient_dto;
+pub use self::bounced_recipient_dto::BouncedRecipientDto;
 pub mod bulk_send_email_options;
 pub use self::bulk_send_email_options::BulkSendEmailOptions;
 pub mod condition_option;
